import time
import uuid

from django_datadog_logger.wsgi import local
from django_datadog_logger.local import release_local


def generate_request_id():
    return str(uuid.uuid4())


class RequestIdMiddleware:
    def __init__(self, get_response=None):
        self.get_response = get_response

    def __call__(self, request):
        request.request_id = generate_request_id()
        request.request_start_time = time.time()
        local.request = request
        response = self.get_response(request)
        response["X-Request-ID"] = request.request_id
        release_local(local)
        return response



from functools import wraps
from uuid import uuid4

from celery import Task
from celery.utils.threads import release_local

from django_datadog_logger.local import Local  # NOQA

local = Local()


def get_celery_request():
    try:
        return local.request
    except AttributeError:
        return None


def store_celery_request(func):
    @wraps(func)
    def function_wrapper(*args, **kwargs):
        try:
            if args and isinstance(args[0], Task) and hasattr(args[0], "request"):
                local.request = args[0].request
            return func(*args, **kwargs)
        finally:
            release_local(local)

    return function_wrapper


__all__ = ["local", "get_celery_request", "store_celery_request"]
